contexttools.detach_instrument_mark_attached_to_component
=========================================================

.. autofunction:: abjad.tools.contexttools.detach_instrument_mark_attached_to_component
